#
# spec file for package lttoolbox
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lttoolbox
%define lname   liblttoolbox3
Summary:        Toolbox for lexical processing and morphological analysis
Version:        3.7.1
Release:        bp155.1.6
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Other
URL:            https://apertium.org/

Source:         https://github.com/apertium/lttoolbox/archive/v%version.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  utfcpp-devel
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-io)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libxml-2.0)

%description
lttoolbox is a toolbox for lexical processing, morphological analysis
and generation of words. Analysis is the process of splitting a word
(e.g. cats) into its lemma 'cat' and the grammatical information
<neutrum,plural>. Generation is the opposite process.

The package provides three programs, lt-comp, the compiler,
lt-proc, the processor, and lt-expand, which generates all possible
mappings between surface forms and lexical forms in the dictionary.

%package -n %lname
Summary:        Library for lexical processing and morphological analysis
Group:          System/Libraries

%description -n %lname
lttoolbox is a toolbox for lexical processing, morphological analysis
and generation of words. Analysis is the process of splitting a word
(e.g. cats) into its lemma 'cat' and the grammatical information
<neutrum,plural>. Generation is the opposite process.

%package devel
Summary:        Development files for the Lexical Toolbox
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
lttoolbox is a toolbox for lexical processing, morphological analysis
and generation of words. Analysis is the process of splitting a word
(e.g. cats) into its lemma 'cat' and the grammatical information
<neutrum,plural>. Generation is the opposite process.

This subpackage contains the development files for lttoolbox.

%prep
%autosetup -p1

%build
autoreconf -fiv
# includedir intentional, cf. bugzilla.opensuse.org/795968
%configure --disable-static --includedir="%_includedir/%name" CPPFLAGS="-I%_includedir/utf8cpp"
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%check
%make_build check

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%_bindir/lt-*
%_bindir/lsx-*
%_datadir/lttoolbox
%_mandir/man1/lsx-*.1*
%_mandir/man1/lt-*.1*
%doc README
%license COPYING

%files -n %lname
%_libdir/liblttoolbox.so.*

%files devel
%_includedir/%name/
%_libdir/liblttoolbox.so
%_libdir/pkgconfig/*.pc

%changelog
* Tue Nov  1 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.7.1
  * Write directly to output stream; Don't hexify single char16_t.
* Fri Oct 28 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.7.0
  * Hardcoded sanity-max state size for case-insensitive matching
  * Deleted FSTProcessor.current_state since confusingly all the
    processors (except transliteration) make a local State called
    current_state
* Mon Jun  6 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.6.6
  * Cleanup lt-proc flag logic and make -C and -g compatible
  * Allow -b and -d to be combined on lt-proc
* Tue Apr 26 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.6.4
  * Support compound analyses where left part has spaces
  * Split multichar non-tag symbols into multiple transitions in ATT
* Mon Mar 21 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.6.1
  * No changelog was provided
* Sun Mar 13 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.6.0
  * No changelog was provided
* Thu Oct 28 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.5.4
  * postgenerator failed when ~ in middle of wblanked word
* Fri Nov 27 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.5.3
  * Support for wordbound blanks stream format.
* Wed Oct 14 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.5.2
  * Support for weights
  * New `lt-proc -x` mode: intergen
* Mon Jul  7 2014 jengelh@inai.de
- Initial package (version 3.3.0~svn55329) for build.opensuse.org
